@@ -68,7 +68,7 @@ class WitterUI():
         self.publicPos = None
         self.showingMore = False
         self.busyCounter = 0
-
+        self.gesture_enabled=True
         #Set the Glade file
         #self.gladefile = "/usr/share/witter/witter.glade"  
         #self.wTree = gtk.glade.XML(self.gladefile) 
@@ -880,6 +880,11 @@ class WitterUI():
         retweet.set_title('Retweet')
         retweet.connect("clicked", self.controller.reTweet)
         hbox0.pack_start(retweet, expand=True)
+        retweet2 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        retweet2.set_title('RT')
+        retweet2.connect("clicked", self.controller.reTweetNew)
+        hbox0.pack_start(retweet2, expand=True)
         #direct message
         dm = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                   hildon.BUTTON_ARRANGEMENT_VERTICAL)
@@ -1411,6 +1416,8 @@ class WitterUI():
 
 
     def gesture(self, widget, direction, startx, starty):
+        if (self.gesture_enabled ==False):
+            return
         self.builder.get_object("hbuttonbox-act1").hide_all()
         self.builder.get_object("hbuttonbox-act2").hide_all()
         self.builder.get_object("hbuttonbox-act3").hide_all()
@@ -1571,6 +1578,11 @@ class WitterUI():
        # Attach callback to the "value-changed" signal
        picker_button.connect("value-changed", self.select_theme, selector)
 
+       gbutton = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
+       gbutton.set_name("HildonButton-thumb")
+       gbutton.set_label("Gestures")
+       gbutton.set_active(self.gesture_enabled)
+       gbutton.connect("toggled", self.gesture_button_toggled)
 
        vbox = gtk.VBox(False, 0)
        vbox.pack_start(bitlyId, True, True, 0)
@@ -1584,6 +1596,7 @@ class WitterUI():
        vbox.pack_start(search_picker_button, True, True, 0)
 
        vbox.pack_start(picker_button, True, True, 0)
+       vbox.pack_start(gbutton, True, True, 0)
 
 
        pannedArea.add_with_viewport(vbox)
@@ -1593,6 +1606,13 @@ class WitterUI():
 
        # This call show the window and also add the window to the stack
        win.show_all()
+    def gesture_button_toggled(self,checkbutton):
+        if (checkbutton.get_active()):
+            print "gestures on"
+            self.gesture_enabled = True
+        else:
+            print "gestures off"
+            self.gesture_enabled = False
 
     def create_theme_selector(self):
        selector = hildon.TouchSelector(text=True)
