@@ -53,6 +53,9 @@ import time
 import pickle
 import gobject
 import cProfile
+import dbus
+import dbus.glib
+import conic 
 #import witter components
 import ui
 import account
@@ -137,6 +140,7 @@ class Witter():
         self.retweettext = ""
         self.selectedUser = ""
         self.theme = "default"
+        self.gestures = True
 
         #
         #go read config file
@@ -175,6 +179,7 @@ class Witter():
         self.ui.theme = self.theme
         self.ui.load_theme_icons()
         self.ui.select_ui_theme(self.theme)
+        self.ui.gesture_enabled = self.gestures
         self.gettingTweets = False
         if (self.activeAccount.getUsername() != "Username"):
             self.start_refresh_threads()
@@ -312,7 +317,10 @@ class Witter():
         self.ui.setTweetText("RT " + retweet)
         self.ui.setCursorAt(0)
 
-
+    def reTweetNew(self,widget,*args):
+        self.ui.hideActionButtons()
+        self.ui.showBottomBar()
+        self.activeAccount.newRetweet(self.retweetid)
 
     def openBrowser(self, widget, url, *args):
         #open a url in a browser
@@ -382,13 +390,18 @@ class Witter():
             try:
                 #self.access_token = config.get("credentials", "access_token")
                 topCol = config.get("UI", "bg_top")
-                print topCol
+                
                 self.bg_top_color = gtk.gdk.color_parse(topCol)
                 bottomCol = config.get("UI", "bg_bottom")
-                print bottomCol
+                
                 self.bg_bottom_color = gtk.gdk.color_parse(bottomCol)
                 self.font_size = int(config.get("UI", "font_size"))
                 self.theme = config.get("UI", "theme")
+                gestures = config.get("UI","gestures_enabled")
+                if (gestures == 'True'):
+                    self.gestures = True
+                else:
+                    self.gestures= False
             except ConfigParser.NoSectionError:
                 print "no text colour setting"
             except ConfigParser.NoOptionError:
@@ -512,6 +525,10 @@ class Witter():
             f.write("bg_bottom = " + self.ui.bg_bottom_color.to_string() + "\n")
             f.write("font_size = " + str(self.font_size) + "\n")
             f.write("theme = " + self.ui.theme + "\n")
+            if self.ui.gesture_enabled:
+                f.write("gestures_enabled = True\n")
+            else:
+                f.write("gestures_enabled = False\n")
             f.write("[refresh_interval]\n")
             f.write("timeline = " + str(self.timelineRefreshInterval) + "\n")
             f.write("mentions = " + str(self.mentionsRefreshInterval) + "\n")
@@ -815,12 +832,14 @@ class Witter():
 
     def getTweetsWrapper(self, get_older=False, more=0, autoval=None):
         self.ui.showBusy(1)
+        self.establish_connection()
         self.activeAccount.getTweets(auto=autoval, older=get_older, get_count=more)
         self.ui.showBusy(-1)
 
 
     def getDMsWrapper(self, get_older=False, autoval=None, more=0, *args):
         self.ui.showBusy(1)
+        self.establish_connection()
         self.activeAccount.getDMs(auto=autoval, older=get_older, get_count=more)
         self.ui.showBusy(-1)
 
@@ -828,17 +847,20 @@ class Witter():
     def getMentionsWrapper(self, get_older=False, autoval=None, more=0, *args):
 
         self.ui.showBusy(1)
+        self.establish_connection()
         self.activeAccount.getMentions(auto=autoval, older=get_older, get_count=more)
         self.ui.showBusy(-1)
 
 
     def getPublicWrapper(self, get_older=False, autoval=None, more=0, *args):
-	    self.ui.showBusy(1)
-	    self.activeAccount.getPublic(auto=autoval, older=get_older, get_count=more)
-	    self.ui.showBusy(-1)
+        self.ui.showBusy(1)
+        self.establish_connection()
+        self.activeAccount.getPublic(auto=autoval, older=get_older, get_count=more)
+        self.ui.showBusy(-1)
 
     def getSearchWrapper(self, get_older=False, autoval=None, more=0, *args):
         self.ui.showBusy(1)
+        self.establish_connection()
         if (autoval == 1):
             #if we manually his search get the latest content of the search box
             searchTerms = self.ui.getEntryText()
@@ -848,12 +870,14 @@ class Witter():
 
     def getFriendsWrapper(self, get_older=False, autoval=None, more=0, *args):
         self.ui.showBusy(1)
+        self.establish_connection()
         self.activeAccount.getFriends()
         self.ui.showBusy(-1)
 
 
     def getUserHistWrapper(self, get_older=False, autoval=None, more=0, *args):
         self.ui.showBusy(1)
+        self.establish_connection()
         user = self.ui.getEntryText()
         self.ui.set_title(self.serviceName + " " + user + " - History")
         self.activeAccount.getUserHistory(friend=user, auto=autoval)
@@ -862,12 +886,14 @@ class Witter():
 
     def followUserWrapper(self, get_older=False, more=0, autoval=None):
         self.ui.showBusy(1)
+        self.establish_connection()
         self.activeAcount.FollowUser(widget, self.reply_to_name)
         self.ui.showBusy(-1)
 
 
     def getTrendsWrapper(self, get_older=False, autoval=None, more=0, *args):
         self.ui.showBusy(1)
+        self.establish_connection()
         self.activeAccount.getTrends()
         self.ui.showBusy(-1)
         return "done"
@@ -1081,6 +1107,33 @@ class Witter():
          elif (curView == self.ui.USERHIST_VIEW):
             self.ui.switch_view_to("user")
             
+    def establish_connection(self):
+        magic = 0xAA55 
+        connection = conic.Connection()
+        connection.connect("connection-event", self.connection_cb, magic)
+
+        # The request_connection method should be called to initialize
+        # some fields of the instance
+        assert(connection.request_connection(conic.CONNECT_FLAG_NONE)) 
+        
+    def connection_cb(self, connection, event, magic):
+        print "connection_cb(%s, %s, %x)" % (connection, event, magic)
+ 	
+        status = event.get_status()
+        error = event.get_error()
+        iap_id = event.get_iap_id()
+        bearer = event.get_bearer_type()
+ 	
+        if status == conic.STATUS_CONNECTED:
+            print "(CONNECTED (%s, %s, %i, %i)" % \
+            (iap_id, bearer, status, error)
+        elif status == conic.STATUS_DISCONNECTED:
+            print "(DISCONNECTED (%s, %s, %i, %i)" % \
+            (iap_id, bearer, status, error)
+        elif status == conic.STATUS_DISCONNECTING:
+            print "(DISCONNECTING (%s, %s, %i, %i)" % \
+            (iap_id, bearer, status, error) 
+            
     def getVersion(self):
         return self.version
 
